==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/cms_real_files_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsRealFilesController do
  fixtures :cms_pages

  def login_as_admin
    login_as("admin")
  end

  describe "GET index" do
    it "should get index" do
      login_as_admin
      get :index
      response.should be_success
      assigns("real_file_pathes").should_not be_nil
    end
  end

  describe "DELETE destroy" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
    end

    it "should delete file" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_files/common/logo.GIF"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, 'public', 'cms', 'logo.GIF')
      File.exist?(uploaded_file_path).should == false

      FileUtils.copy_file(fixture_file_path, uploaded_file_path)
      File.exist?(uploaded_file_path).should == true

      delete(:destroy, {:path => "public/cms/logo.GIF"})
      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == false
    end
  end

  test "filetree_sort should return sorted pathes" do
    Dir.stub!(:glob).and_return([
      '/test_path/public/test_01',
      '/test_path/public/test_01.txt',
      '/test_path/public/test_01/test_01.txt',
      '/test_path/public/test_01/test_01-00000000000000.txt',
      '/test_path/public/test_02',
      '/test_path/public/test_02/test_03',
      '/test_path/public/test_02/test_04',
      '/test_path/public/test_02/test_04/test_04_02.txt',
      '/test_path/public/test_02/test_04/test_04_01.txt'
    ])

    File.stub!(:directory?).with('/test_path/public').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_01').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02/test_03').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04').and_return(true)

    File.stub!(:directory?).with('/test_path/public/test_01.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_01/test_01-00000000000000.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_01/test_01.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04/test_04_02.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04/test_04_01.txt').and_return(false)

    File.stub!(:expand_path).and_return('/test_path')

    login_as_admin
    get :index
    controller.instance_variable_get(:@real_file_pathes).should == [
      '/public',
      '/public/test_01.txt',
      '/public/test_01',
      '/public/test_01/test_01.txt',
      '/public/test_02',
      '/public/test_02/test_03',
      '/public/test_02/test_04',
      '/public/test_02/test_04/test_04_01.txt',
      '/public/test_02/test_04/test_04_02.txt'
    ]
  end

  describe "DELETE destroy" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
    end
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/cms_real_files_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsRealFilesController do
  fixtures :cms_pages

  def login_as_admin
    login_as("admin")
  end

  describe "GET index" do
    before(:each) do
      Dir.stub!(:glob).and_return([
      '/test_path/public/test_01',
      '/test_path/public/test_01.txt'
      ])
      File.stub!(:expand_path).and_return('/test_path')
    end
      
    it "should get index" do
      login_as_admin
      get :index
      response.should be_success
      assigns("real_file_pathes").should_not be_nil
    end
  end

  describe "DELETE destroy" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
    end

    it "should delete file" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_files/common/logo.GIF"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, 'public', 'cms', 'logo.GIF')
      File.exist?(uploaded_file_path).should == false

      FileUtils.copy_file(fixture_file_path, uploaded_file_path)
      File.exist?(uploaded_file_path).should == true

      delete(:destroy, {:path => "public/cms/logo.GIF"})
      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == false
    end
  end

  test "filetree_sort should return sorted pathes" do
    Dir.stub!(:glob).and_return([
      '/test_path/public/test_01',
      '/test_path/public/test_01.txt',
      '/test_path/public/test_01/test_01.txt',
      '/test_path/public/test_01/test_01-00000000000000.txt',
      '/test_path/public/test_02',
      '/test_path/public/test_02/test_03',
      '/test_path/public/test_02/test_04',
      '/test_path/public/test_02/test_04/test_04_02.txt',
      '/test_path/public/test_02/test_04/test_04_01.txt'
    ])

    File.stub!(:directory?).with('/test_path/public').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_01').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02/test_03').and_return(true)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04').and_return(true)

    File.stub!(:directory?).with('/test_path/public/test_01.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_01/test_01-00000000000000.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_01/test_01.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04/test_04_02.txt').and_return(false)
    File.stub!(:directory?).with('/test_path/public/test_02/test_04/test_04_01.txt').and_return(false)

    File.stub!(:expand_path).and_return('/test_path')

    login_as_admin
    get :index
    controller.instance_variable_get(:@real_file_pathes).should == [
      '/public',
      '/public/test_01.txt',
      '/public/test_01',
      '/public/test_01/test_01.txt',
      '/public/test_02',
      '/public/test_02/test_03',
      '/public/test_02/test_04',
      '/public/test_02/test_04/test_04_01.txt',
      '/public/test_02/test_04/test_04_02.txt'
    ]
  end

  describe "DELETE destroy" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
    end
  end

end
